package de.intevation.flys.client.server;

import org.w3c.dom.Document;

import com.google.gwt.user.server.rpc.RemoteServiceServlet;

import de.intevation.artifacts.common.ArtifactNamespaceContext;
import de.intevation.artifacts.common.utils.XMLUtils;

import de.intevation.artifacts.httpclient.exceptions.ConnectionException;
import de.intevation.artifacts.httpclient.http.HttpClient;
import de.intevation.artifacts.httpclient.http.HttpClientImpl;
import de.intevation.artifacts.httpclient.http.response.DocumentResponseHandler;

import de.intevation.flys.client.shared.exceptions.ServerException;
import de.intevation.flys.client.shared.model.Collection;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class DoCollectionAction extends RemoteServiceServlet {

    public static final String XPATH_RESULT      = "/art:result/text()";
    public static final String OPERATION_FAILURE = "FAILED";
    public static final String FAILURE_EXCEPTION = "collection_action_failed";


    protected void doAction(Collection c, Document action, String url)
    throws    ServerException
    {
        HttpClient client = new HttpClientImpl(url);

        try {
            Document res  = (Document) client.doCollectionAction(
                action, c.identifier(),
                new DocumentResponseHandler());

            String result = XMLUtils.xpathString(
                res,
                XPATH_RESULT,
                ArtifactNamespaceContext.INSTANCE);

            if (result == null || result.equals(OPERATION_FAILURE)) {
                System.err.println("Operation failed.");
                throw new ServerException(FAILURE_EXCEPTION);
            }
        }
        catch (ConnectionException ce) {
            System.err.println(ce.getLocalizedMessage());
            throw new ServerException(FAILURE_EXCEPTION);
        }
    }
}
